@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -9,11 +9,11 @@
 
 #include <KLocalizedString>
 
-#include <QProcess>
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 #include <QDBusInterface>
 #include <QDBusReply>
+#include <QProcess>
 
 #if !defined(Q_OS_WIN)
 #include <unistd.h>
@@ -110,8 +110,8 @@ bool QEkigaDialer::dialNumber(const QString &number)
 
 bool QEkigaDialer::sendSms(const QString &number, const QString &text)
 {
-    Q_UNUSED(number);
-    Q_UNUSED(text);
+    Q_UNUSED(number)
+    Q_UNUSED(text)
     mErrorMessage = i18n("Sending an SMS is currently not supported on Ekiga.");
     return false;
 }
