@@ -15,7 +15,8 @@ class QLabel;
 
 class KTextEdit;
 
-namespace KContacts {
+namespace KContacts
+{
 class PhoneNumber;
 }
 
