@@ -15,7 +15,8 @@
 
 #include <QVariant>
 
-namespace Akonadi {
+namespace Akonadi
+{
 /**
  * @short Attribute to store contact specific meta data.
  *
@@ -32,7 +33,7 @@ public:
     /**
      * Destroys the contact meta data attribute.
      */
-    ~ContactMetaDataAttribute();
+    ~ContactMetaDataAttribute() override;
 
     /**
      * Sets the meta @p data.
