@@ -18,7 +18,8 @@
 
 class KJob;
 
-namespace Akonadi {
+namespace Akonadi
+{
 class ContactGroupModel;
 class Monitor;
 
