@@ -1,20 +1,7 @@
 /*
-  Copyright 2010 Tobias Koenig <tokoe@kde.org>
+  SPDX-FileCopyrightText: 2010 Tobias Koenig <tokoe@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef ADDEMAILADDRESSJOB_H
@@ -24,7 +11,8 @@
 
 #include <KJob>
 
-namespace Akonadi {
+namespace Akonadi
+{
 class Item;
 /**
  * @short A job to add a new contact with a given email address to Akonadi.
@@ -65,6 +53,7 @@ public:
     void setInteractive(bool b);
 Q_SIGNALS:
     void successMessage(const QString &message);
+
 private:
     //@cond PRIVATE
     class Private;
