@@ -13,7 +13,8 @@
 
 #include "abstractcontactgroupformatter.h"
 
-namespace Akonadi {
+namespace Akonadi
+{
 /**
  * @short A class that formats a contact group as HTML code.
  *
