@@ -10,8 +10,8 @@
 #ifndef ADDRESSLOCATIONWIDGET_H
 #define ADDRESSLOCATIONWIDGET_H
 
-#include <QWidget>
 #include <KContacts/Address>
+#include <QWidget>
 
 class QStackedWidget;
 class QCheckBox;
@@ -19,18 +19,15 @@ class KLineEdit;
 class KComboBox;
 class QPushButton;
 
-namespace ContactEditor {
-
+namespace ContactEditor
+{
 class SelectAddressTypeComboBox;
 
 class AddressLocationWidget : public QWidget
 {
     Q_OBJECT
 public:
-    enum Mode {
-        CreateAddress = 0,
-        ModifyAddress
-    };
+    enum Mode { CreateAddress = 0, ModifyAddress };
 
     explicit AddressLocationWidget(QWidget *parent = nullptr);
     ~AddressLocationWidget() override;
@@ -49,11 +46,13 @@ Q_SIGNALS:
     void addNewAddress(const KContacts::Address &address);
     void updateAddress(const KContacts::Address &address, int index);
     void updateAddressCanceled();
+    void removeAddress(int index);
 
 private:
     void slotChanged();
     void slotAddAddress();
     void slotUpdateAddress();
+    void slotRemoveAddress();
     void slotCancelModifyAddress();
     void fillCountryCombo();
     void switchMode();
@@ -67,6 +66,7 @@ private:
     KLineEdit *mStreetEdit = nullptr;
     KComboBox *mCountryCombo = nullptr;
     QPushButton *mAddAddress = nullptr;
+    QPushButton *mRemoveAddress = nullptr;
     QPushButton *mModifyAddress = nullptr;
     QPushButton *mCancelAddress = nullptr;
     QStackedWidget *mButtonStack = nullptr;
