@@ -13,14 +13,14 @@
 
 #include <KContacts/Address>
 
-namespace ContactEditor {
-
+namespace ContactEditor
+{
 class AddressModel : public QAbstractListModel
 {
     Q_OBJECT
 public:
     explicit AddressModel(QObject *parent = nullptr);
-    ~AddressModel();
+    ~AddressModel() override;
 
     KContacts::Address::List addresses() const;
     void setAddresses(const KContacts::Address::List &addresses);
@@ -28,8 +28,8 @@ public:
     void replaceAddress(const KContacts::Address &address, int row);
     void removeAddress(int row);
 
-    int rowCount(const QModelIndex& parent) const override;
-    QVariant data(const QModelIndex& index, int role) const override;
+    int rowCount(const QModelIndex &parent) const override;
+    QVariant data(const QModelIndex &index, int role) const override;
 
 private:
     KContacts::Address::List mAddresses;
