@@ -2,7 +2,7 @@
     This file is part of Contact Editor.
 
     SPDX-FileCopyrightText: 2010 Tobias Koenig <tokoe@kde.org>
-    SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -12,13 +12,14 @@
 
 #include <QStyledItemDelegate>
 class QAbstractItemView;
-namespace ContactEditor {
+namespace ContactEditor
+{
 class CustomFieldsListDelegate : public QStyledItemDelegate
 {
     Q_OBJECT
 public:
     explicit CustomFieldsListDelegate(QAbstractItemView *view, QObject *parent = nullptr);
-    ~CustomFieldsListDelegate();
+    ~CustomFieldsListDelegate() override;
 
     QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
