@@ -17,13 +17,10 @@ class CustomFieldsModel : public QAbstractItemModel
 {
     Q_OBJECT
 public:
-    enum Role {
-        TypeRole = Qt::UserRole,
-        ScopeRole
-    };
+    enum Role { TypeRole = Qt::UserRole, ScopeRole };
 
     explicit CustomFieldsModel(QObject *parent = nullptr);
-    ~CustomFieldsModel();
+    ~CustomFieldsModel() override;
 
     void setCustomFields(const CustomField::List &addresses);
     CustomField::List customFields() const;
