@@ -11,17 +11,19 @@
 #define MESSAGINGWIDGETLISTER_H
 
 #include "../../widgets/kwidgetlister_p.h"
-namespace KContacts {
+namespace KContacts
+{
 class Addressee;
 }
-namespace ContactEditor {
+namespace ContactEditor
+{
 class MessagingWidget;
 class MessagingWidgetLister : public KWidgetLister
 {
     Q_OBJECT
 public:
     explicit MessagingWidgetLister(QWidget *parent = nullptr);
-    ~MessagingWidgetLister();
+    ~MessagingWidgetLister() override;
 
     void loadContact(const KContacts::Addressee &contact);
     void storeContact(KContacts::Addressee &contact) const;
