@@ -10,13 +10,15 @@
 #ifndef NICKNAMEWIDGET_H
 #define NICKNAMEWIDGET_H
 
-#include <QWidget>
 #include "contacteditor_private_export.h"
+#include <QWidget>
 class KLineEdit;
-namespace KContacts {
+namespace KContacts
+{
 class Addressee;
 }
-namespace ContactEditor {
+namespace ContactEditor
+{
 class CONTACTEDITOR_TESTS_EXPORT NicknameWidget : public QWidget
 {
     Q_OBJECT
@@ -26,6 +28,7 @@ public:
     void loadContact(const KContacts::Addressee &contact);
     void storeContact(KContacts::Addressee &contact) const;
     void setReadOnly(bool readOnly);
+
 private:
     KLineEdit *mNickName = nullptr;
 };
