@@ -1,19 +1,20 @@
 /*
     This file is part of Contact Editor.
 
-    SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef PHONETYPEDIALOG_H
 #define PHONETYPEDIALOG_H
 
-#include <QDialog>
-#include <KContacts/PhoneNumber>
 #include "contacteditor_private_export.h"
+#include <KContacts/PhoneNumber>
+#include <QDialog>
 class QButtonGroup;
 
-namespace ContactEditor {
+namespace ContactEditor
+{
 /**
  * A dialog for editing phone number types.
  */
