@@ -1,7 +1,7 @@
 /*
     This file is part of Contact Editor.
 
-    SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -11,12 +11,12 @@
 
 #include <QObject>
 
-class PreferredLineEditWidget : public QObject
+class PreferredLineEditWidgetTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit PreferredLineEditWidget(QObject *parent = nullptr);
-    ~PreferredLineEditWidget();
+    explicit PreferredLineEditWidgetTest(QObject *parent = nullptr);
+    ~PreferredLineEditWidgetTest();
 
 private Q_SLOTS:
     void shouldHaveDefaultValue();
